pub struct PositionExtension {}Trait Implementations
Sourceimpl AsBindGroup for PositionExtension
impl AsBindGroup for PositionExtension
type Param = (Res<'static, RenderAssets<GpuImage>>, Res<'static, FallbackImage>, Res<'static, RenderAssets<GpuShaderStorageBuffer>>)
Sourcefn unprepared_bind_group(
&self,
layout: &BindGroupLayout,
render_device: &RenderDevice,
(images, fallback_image, storage_buffers): &mut SystemParamItem<'_, '_, Self::Param>,
force_no_bindless: bool,
) -> Result<UnpreparedBindGroup, AsBindGroupError>
fn unprepared_bind_group( &self, layout: &BindGroupLayout, render_device: &RenderDevice, (images, fallback_image, storage_buffers): &mut SystemParamItem<'_, '_, Self::Param>, force_no_bindless: bool, ) -> Result<UnpreparedBindGroup, AsBindGroupError>
Returns a vec of (binding index,
OwnedBindingResource). Read morefn bind_group_data(&self) -> Self::Data
Sourcefn bind_group_layout_entries(
render_device: &RenderDevice,
force_no_bindless: bool,
) -> Vec<BindGroupLayoutEntry>
fn bind_group_layout_entries( render_device: &RenderDevice, force_no_bindless: bool, ) -> Vec<BindGroupLayoutEntry>
Returns a vec of bind group layout entries. Read more
fn bindless_descriptor() -> Option<BindlessDescriptor>
Sourcefn bindless_slot_count() -> Option<BindlessSlabResourceLimit>
fn bindless_slot_count() -> Option<BindlessSlabResourceLimit>
The number of slots per bind group, if bindless mode is enabled. Read more
Sourcefn bindless_supported(_: &RenderDevice) -> bool
fn bindless_supported(_: &RenderDevice) -> bool
True if the hardware actually supports bindless textures for this
type, taking the device and driver capabilities into account. Read more
Sourcefn as_bind_group(
&self,
layout: &BindGroupLayout,
render_device: &RenderDevice,
param: &mut <Self::Param as SystemParam>::Item<'_, '_>,
) -> Result<PreparedBindGroup, AsBindGroupError>
fn as_bind_group( &self, layout: &BindGroupLayout, render_device: &RenderDevice, param: &mut <Self::Param as SystemParam>::Item<'_, '_>, ) -> Result<PreparedBindGroup, AsBindGroupError>
Creates a bind group for
self matching the layout defined in AsBindGroup::bind_group_layout.Sourcefn bind_group_layout(render_device: &RenderDevice) -> BindGroupLayoutwhere
Self: Sized,
fn bind_group_layout(render_device: &RenderDevice) -> BindGroupLayoutwhere
Self: Sized,
Creates the bind group layout matching all bind groups returned by
AsBindGroup::as_bind_groupimpl Asset for PositionExtension
Sourceimpl Clone for PositionExtension
impl Clone for PositionExtension
Sourcefn clone(&self) -> PositionExtension
fn clone(&self) -> PositionExtension
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PositionExtension
impl Debug for PositionExtension
Sourceimpl Default for PositionExtension
impl Default for PositionExtension
Sourcefn default() -> PositionExtension
fn default() -> PositionExtension
Returns the “default value” for a type. Read more
Sourceimpl MaterialExtension for PositionExtension
impl MaterialExtension for PositionExtension
Sourcefn fragment_shader() -> ShaderRef
fn fragment_shader() -> ShaderRef
Returns this material’s fragment shader. If
ShaderRef::Default is returned, the base material mesh fragment shader
will be used.Sourcefn vertex_shader() -> ShaderRef
fn vertex_shader() -> ShaderRef
Returns this material’s vertex shader. If
ShaderRef::Default is returned, the base material mesh vertex shader
will be used.fn alpha_mode() -> Option<AlphaMode>
Sourcefn prepass_vertex_shader() -> ShaderRef
fn prepass_vertex_shader() -> ShaderRef
Returns this material’s prepass vertex shader. If
ShaderRef::Default is returned, the base material prepass vertex shader
will be used.Sourcefn prepass_fragment_shader() -> ShaderRef
fn prepass_fragment_shader() -> ShaderRef
Returns this material’s prepass fragment shader. If
ShaderRef::Default is returned, the base material prepass fragment shader
will be used.Sourcefn deferred_vertex_shader() -> ShaderRef
fn deferred_vertex_shader() -> ShaderRef
Returns this material’s deferred vertex shader. If
ShaderRef::Default is returned, the base material deferred vertex shader
will be used.Sourcefn deferred_fragment_shader() -> ShaderRef
fn deferred_fragment_shader() -> ShaderRef
Returns this material’s prepass fragment shader. If
ShaderRef::Default is returned, the base material deferred fragment shader
will be used.Sourcefn specialize(
pipeline: &MaterialExtensionPipeline,
descriptor: &mut RenderPipelineDescriptor,
layout: &MeshVertexBufferLayoutRef,
key: MaterialExtensionKey<Self>,
) -> Result<(), SpecializedMeshPipelineError>
fn specialize( pipeline: &MaterialExtensionPipeline, descriptor: &mut RenderPipelineDescriptor, layout: &MeshVertexBufferLayoutRef, key: MaterialExtensionKey<Self>, ) -> Result<(), SpecializedMeshPipelineError>
Customizes the default
RenderPipelineDescriptor for a specific entity using the entity’s
MaterialPipelineKey and MeshVertexBufferLayoutRef as input.
Specialization for the base material is applied before this function is called.Sourceimpl TypePath for PositionExtension
impl TypePath for PositionExtension
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl VisitAssetDependencies for PositionExtension
impl VisitAssetDependencies for PositionExtension
fn visit_dependencies(&self, visit: &mut impl FnMut(UntypedAssetId))